@@ -76,7 +76,7 @@ var _ = Describe("kube-controllers IPAM FV tests (etcd mode)", func() {
 
 		// Wait for the apiserver to be available.
 		Eventually(func() error {
-			_, err := k8sClient.CoreV1().Namespaces().List(metav1.ListOptions{})
+			_, err := k8sClient.CoreV1().Namespaces().List(context.Background(), metav1.ListOptions{})
 			return err
 		}, 30*time.Second, 1*time.Second).Should(BeNil())
 
@@ -118,7 +118,7 @@ var _ = Describe("kube-controllers IPAM FV tests (etcd mode)", func() {
 
 		// Create a kubernetes node.
 		kn := &v1.Node{ObjectMeta: metav1.ObjectMeta{Name: kNodeName}}
-		_, err := k8sClient.CoreV1().Nodes().Create(kn)
+		_, err := k8sClient.CoreV1().Nodes().Create(context.Background(), kn, metav1.CreateOptions{})
 		Expect(err).NotTo(HaveOccurred())
 
 		// Create a Calico node with a reference to it.
@@ -139,9 +139,9 @@ var _ = Describe("kube-controllers IPAM FV tests (etcd mode)", func() {
 		// Create and delete an unrelated node. This should trigger the controller
 		// to do a sync.
 		kn2 := &v1.Node{ObjectMeta: metav1.ObjectMeta{Name: "other-node"}}
-		_, err = k8sClient.CoreV1().Nodes().Create(kn2)
+		_, err = k8sClient.CoreV1().Nodes().Create(context.Background(), kn2, metav1.CreateOptions{})
 		Expect(err).NotTo(HaveOccurred())
-		err = k8sClient.CoreV1().Nodes().Delete(kn2.Name, nil)
+		err = k8sClient.CoreV1().Nodes().Delete(context.Background(), kn2.Name, metav1.DeleteOptions{})
 		Expect(err).NotTo(HaveOccurred())
 
 		// The IPAM allocation should be untouched, since the Kubernetes node which is bound to
@@ -151,7 +151,7 @@ var _ = Describe("kube-controllers IPAM FV tests (etcd mode)", func() {
 		}, 5*time.Second, 1*time.Second).ShouldNot(HaveOccurred())
 
 		// Delete the Kubernetes node with the allocation.
-		err = k8sClient.CoreV1().Nodes().Delete(kn.Name, nil)
+		err = k8sClient.CoreV1().Nodes().Delete(context.Background(), kn.Name, metav1.DeleteOptions{})
 		Expect(err).NotTo(HaveOccurred())
 
 		// Now the IP should have been cleaned up.
@@ -169,7 +169,7 @@ var _ = Describe("kube-controllers IPAM FV tests (etcd mode)", func() {
 
 		// Create a kubernetes node.
 		kn := &v1.Node{ObjectMeta: metav1.ObjectMeta{Name: commonNodeName}}
-		_, err := k8sClient.CoreV1().Nodes().Create(kn)
+		_, err := k8sClient.CoreV1().Nodes().Create(context.Background(), kn, metav1.CreateOptions{})
 		Expect(err).NotTo(HaveOccurred())
 
 		// Create a Calico node without a node reference. Be extra tricky, by naming the calico node the
@@ -190,9 +190,9 @@ var _ = Describe("kube-controllers IPAM FV tests (etcd mode)", func() {
 		// Create and delete an unrelated Kubernetes node. This should trigger the controller
 		// to do a sync.
 		kn2 := &v1.Node{ObjectMeta: metav1.ObjectMeta{Name: "other-node"}}
-		_, err = k8sClient.CoreV1().Nodes().Create(kn2)
+		_, err = k8sClient.CoreV1().Nodes().Create(context.Background(), kn2, metav1.CreateOptions{})
 		Expect(err).NotTo(HaveOccurred())
-		err = k8sClient.CoreV1().Nodes().Delete(kn2.Name, nil)
+		err = k8sClient.CoreV1().Nodes().Delete(context.Background(), kn2.Name, metav1.DeleteOptions{})
 		Expect(err).NotTo(HaveOccurred())
 
 		// The IPAM allocation should be untouched.
@@ -201,7 +201,7 @@ var _ = Describe("kube-controllers IPAM FV tests (etcd mode)", func() {
 		}, 5*time.Second, 1*time.Second).ShouldNot(HaveOccurred())
 
 		// Delete the Kubernetes node with the same name as the Calico node.
-		err = k8sClient.CoreV1().Nodes().Delete(kn.Name, nil)
+		err = k8sClient.CoreV1().Nodes().Delete(context.Background(), kn.Name, metav1.DeleteOptions{})
 		Expect(err).NotTo(HaveOccurred())
 
 		// The IPAM allocation should still be untouched.
@@ -216,9 +216,9 @@ var _ = Describe("kube-controllers IPAM FV tests (etcd mode)", func() {
 		// Create and delete an unrelated Kubernetes node. This should trigger the controller
 		// to do a sync.
 		// TODO: Right now we only trigger the controller off of k8s node events, not Calico node events.
-		_, err = k8sClient.CoreV1().Nodes().Create(kn2)
+		_, err = k8sClient.CoreV1().Nodes().Create(context.Background(), kn2, metav1.CreateOptions{})
 		Expect(err).NotTo(HaveOccurred())
-		err = k8sClient.CoreV1().Nodes().Delete(kn2.Name, nil)
+		err = k8sClient.CoreV1().Nodes().Delete(context.Background(), kn2.Name, metav1.DeleteOptions{})
 		Expect(err).NotTo(HaveOccurred())
 
 		// The IPAM allocation should still be untouched.
@@ -234,7 +234,7 @@ var _ = Describe("kube-controllers IPAM FV tests (etcd mode)", func() {
 		// Create a kubernetes node.
 		commonNodeName := "common-node-name"
 		kn := &v1.Node{ObjectMeta: metav1.ObjectMeta{Name: commonNodeName}}
-		_, err := k8sClient.CoreV1().Nodes().Create(kn)
+		_, err := k8sClient.CoreV1().Nodes().Create(context.Background(), kn, metav1.CreateOptions{})
 		Expect(err).NotTo(HaveOccurred())
 
 		// Allocate an IP address on a node that doesn't exist.
@@ -248,9 +248,9 @@ var _ = Describe("kube-controllers IPAM FV tests (etcd mode)", func() {
 		// Create and delete an unrelated Kubernetes node. This should trigger the controller
 		// to do a sync.
 		kn2 := &v1.Node{ObjectMeta: metav1.ObjectMeta{Name: "other-node"}}
-		_, err = k8sClient.CoreV1().Nodes().Create(kn2)
+		_, err = k8sClient.CoreV1().Nodes().Create(context.Background(), kn2, metav1.CreateOptions{})
 		Expect(err).NotTo(HaveOccurred())
-		err = k8sClient.CoreV1().Nodes().Delete(kn2.Name, nil)
+		err = k8sClient.CoreV1().Nodes().Delete(context.Background(), kn2.Name, metav1.DeleteOptions{})
 		Expect(err).NotTo(HaveOccurred())
 
 		// Now the allocation should be cleaned up.
@@ -275,9 +275,9 @@ var _ = Describe("kube-controllers IPAM FV tests (etcd mode)", func() {
 		// Create and delete an unrelated Kubernetes node. This should trigger the controller
 		// to do a sync.
 		kn2 := &v1.Node{ObjectMeta: metav1.ObjectMeta{Name: "other-node"}}
-		_, err = k8sClient.CoreV1().Nodes().Create(kn2)
+		_, err = k8sClient.CoreV1().Nodes().Create(context.Background(), kn2, metav1.CreateOptions{})
 		Expect(err).NotTo(HaveOccurred())
-		err = k8sClient.CoreV1().Nodes().Delete(kn2.Name, nil)
+		err = k8sClient.CoreV1().Nodes().Delete(context.Background(), kn2.Name, metav1.DeleteOptions{})
 		Expect(err).NotTo(HaveOccurred())
 
 		// The IP should have been cleaned up since it is not attached to any Kubernetes or Calico node.
